﻿using System;
using System.Collections.Generic;
using System.Xml;
namespace Scribd.Net
{
    /// <summary>
    /// The response from Scribd.
    /// </summary>
    internal sealed class Response : XmlDocument, IDisposable
    {
        /// <summary>
        /// Default constructor
        /// </summary>
        public Response(string xml)
            : base()
        {
            try
            {
                this.InnerXml = xml;
            }
            catch (System.Exception ex)
            {
                Service.OnErrorOccurred(666, ex.Message, ex);
            }
        }

        /// <summary>
        /// Status of the response
        /// </summary>
        public string Status
        {
            get
            {
                if (this.HasChildNodes)
                {
                    XmlNode _node = this.SelectSingleNode(@"/rsp");
                    return _node.Attributes["stat"].Value;
                }
                return "unknown";
            }
        }

        /// <summary>
        /// Errors associated with the response.
        /// </summary>
        public Dictionary<int, string> ErrorList
        {
            get
            {
                Dictionary<int, string> _result = new Dictionary<int, string>();
                if (this.HasChildNodes)
                {
                    foreach (XmlNode _node in this.GetElementsByTagName("error"))
                    {
                        int _code = int.Parse(_node.Attributes["code"].Value);
                        string _msg = _node.Attributes["message"].Value;
                        _result.Add(_code, _msg);
                    }
                }
                return _result;
            }
        }

        #region IDisposable Members

        public void Dispose()
        {
            // Sink it.
        }

        #endregion
    }
}